@@ -18,8 +18,6 @@ class FfmpegRecordThread(threading.Thread):
         :param timeout: 超时断开连接，设定时间，默认5s,单位为微妙级
         :param kwargs:
         """
-        super(FfmpegRecordThread, self).__init__(**kwargs)
-
         self.create_time = datetime.now()
         self.name = name
         self.stream_url = stream_url
@@ -30,12 +28,15 @@ class FfmpegRecordThread(threading.Thread):
 
         sub_shell = ''
         if 'rtsp_transport' in kwargs:
-            sub_shell = '-rtsp_transport {} '.format(kwargs['rtsp_transport'])
+            sub_shell = '-rtsp_transport {} '.format(kwargs.pop('rtsp_transport'))
         if 'stimeout' in kwargs:
-            sub_shell += '-stimeout {} '.format(kwargs['stimeout'])
+            sub_shell += '-stimeout {} '.format(kwargs.pop('stimeout'))
         else:
             sub_shell += '-rw_timeout {} '.format(timeout)
 
+        super(FfmpegRecordThread, self).__init__(**kwargs)
+
+
         self.shell_cmd_mp4 = (
             'ffmpeg '
             '-y '                                     # 覆盖输出文件
